@@ -1,10 +1,10 @@
-$Getopt::EvaP::VERSION |= '2.3.1';
+$Getopt::EvaP::VERSION |= '2.3.2';
 
 package Getopt::EvaP; 
 
 # EvaP.pm - Evaluate Parameters 2.3 for Perl (the getopt et.al. replacement)
 #
-# lusol@lehigh.EDU, 94/10/28
+# Stephen.O.Lidie@Lehigh.EDU, 94/10/28
 #
 # Made to conform, as much as possible, to the C function evap. The C, Perl
 # and Tcl versions of evap are patterned after the Control Data procedure
@@ -16,7 +16,7 @@ package Getopt::EvaP;
 #
 # Stephen O. Lidie, Lehigh University Computing Center.
 #
-# Copyright (C) 1993 - 1997 by Stephen O. Lidie.  All rights reserved.
+# Copyright (C) 1993 - 1998 by Stephen O. Lidie.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the same terms as Perl itself.
@@ -27,7 +27,7 @@ package Getopt::EvaP;
 
 =head1 NAME
 
- Getopt::EvaP() - evaluate Perl command line parameters.
+Getopt::EvaP - evaluate Perl command line parameters.
 
 =head1 SYNOPSIS
 
@@ -36,6 +36,11 @@ package Getopt::EvaP;
 
  EvaP \@PDT, \@MM, \%OPT;
 
+=head1 EXPORT
+
+C<use Getopt::EvaP> exports the subs C<EvaP> and C<EvaP_PAC> into your
+name space.
+
 =head1 DESCRIPTION
 
 B<@PDT>
@@ -51,7 +56,7 @@ results.  If specified, the historical behaviour of modifying the calling
 routines' namespace by storing option values in B<%Options>, B<%options> and
 B<$opt*> is disabled.
 
-B<** Introduction **>
+=head2 Introduction
 
 Function Evaluate Parameters parses a Perl command line in a simple and
 consistent manner, performs type checking of parameter values, and provides
@@ -70,7 +75,7 @@ In this case there are two parameters and a file_list consisting of a
 single file name for the cc command.
 
 
-B<** Parameter Description Table (PDT) Syntax **>
+=head2 Parameter Description Table (PDT) Syntax
 
 Here is the PDT syntax.  Optional constructs are enclosed in [], and the
 | character separates possible values in a list.
@@ -104,7 +109,7 @@ I<default_variable>
 is an environment variable - see the section Usage Notes
 for complete details.
 
-B<** Usage Notes **>
+=head2 Usage Notes
 
 Usage is similar to getopt/getopts/newgetopt: define a Parameter
 Description Table declaring a list of command line parameters, their
@@ -187,7 +192,7 @@ So, for example, D_DISCI_DO would name a default variable for the
 display_option (do) parameter of the display_command_information
 (disci) command.  Works for MS-DOS and Unix.
 
-Example:
+=head1 Example
 
  #!/usr/local/bin/perl
      
@@ -301,7 +306,7 @@ Every command using Evaluate Parameters automatically has a
 I<-help> switch which displays parameter help; no special code is
 required in your application.
 
-B<** Customization of EvaP's Help Output **>
+=head2 Customization of EvaP's Help Output
 
 There are several Help Hook strings that can be altered to customize
 B<EvaP>'s help output.  Currently there is only one general area that can
@@ -367,7 +372,7 @@ widget is not created.  An easy solution is to ensure that your Help
 Hook text contains said string, just like the code snippet above;
 otherwise you must manually add the required Tk code yourself.
 
-B<** Human Interface Guidelines **>
+=head2 Human Interface Guidelines
 
 To make Evaluate Parameters successful, you, the application developer, must
 follow certain conventions when choosing parameter names and aliases.
@@ -402,7 +407,7 @@ command line parameters.
 
 =back
 
-B<** Variables MANPAGER, PAGER and D_EVAP_DO_PAGE **>
+=head2 Variables MANPAGER, PAGER and D_EVAP_DO_PAGE
 
 The environment variable MANPAGER (or PAGER) is used to control the
 display of help information generated by Evaluate Parameters.  If
@@ -414,7 +419,7 @@ The boolean environment variable D_EVAP_DO_PAGE can be set to FALSE/NO/OFF/0,
 any case, to disable this automatic paging feature (or you can set your
 paging program to I<cat>).
 
-B<** Return Values **>
+=head2 Return Values
 
 B<EvaP()> behaves differently depending upon whether it's called to parse an 
 application's command line, or as an embedded command line parser
@@ -441,7 +446,7 @@ application's command line, or as an embedded command line parser
  genPerlTk, generate_PerlTk_program(1)
  genTclTk, generate_TclTk_program(1)
 
- All available from directory ftp.Lehigh.EDU:/pub/evap/evap-2.x.
+ All available from directory F<ftp://ftp.Lehigh.EDU:/pub/evap/evap-2.x/>.
 
 =head1 AUTHOR
 
@@ -466,9 +471,12 @@ Stephen O. Lidie <lusol@Lehigh.EDU>
    . Fix Makefile.PL so it behaves properly.  Convert nroff man data to pod
      format.
 
+ Stephen.O.Lidie@Lehigh.EDU 98/01/14 (PDT version 2.0)  Version 2.3.2
+   . Incorporate Achim Bohnet's POD patch while updating for Win32.
+
 =head1 COPYRIGHT
 
-Copyright (C) 1993 - 1997 Stephen O. Lidie. All rights reserved.
+Copyright (C) 1993 - 1998 Stephen O. Lidie. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
